# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetPushGroupResult',
    'AwaitableGetPushGroupResult',
    'get_push_group',
    'get_push_group_output',
]

@pulumi.output_type
class GetPushGroupResult:
    """
    A collection of values returned by getPushGroup.
    """
    def __init__(__self__, app_id=None, id=None, source_group_id=None, status=None, target_group_id=None):
        if app_id and not isinstance(app_id, str):
            raise TypeError("Expected argument 'app_id' to be a str")
        pulumi.set(__self__, "app_id", app_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if source_group_id and not isinstance(source_group_id, str):
            raise TypeError("Expected argument 'source_group_id' to be a str")
        pulumi.set(__self__, "source_group_id", source_group_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if target_group_id and not isinstance(target_group_id, str):
            raise TypeError("Expected argument 'target_group_id' to be a str")
        pulumi.set(__self__, "target_group_id", target_group_id)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> _builtins.str:
        """
        The ID of the Okta Application.
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Push Group ID
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="sourceGroupId")
    def source_group_id(self) -> _builtins.str:
        """
        The ID of the source group in Okta.
        """
        return pulumi.get(self, "source_group_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The status of the push group mapping. Valid values: `ACTIVE` and `INACTIVE`
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="targetGroupId")
    def target_group_id(self) -> _builtins.str:
        """
        The ID of the existing target group for the push group mapping. This is used to link to an existing group
        """
        return pulumi.get(self, "target_group_id")


class AwaitableGetPushGroupResult(GetPushGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPushGroupResult(
            app_id=self.app_id,
            id=self.id,
            source_group_id=self.source_group_id,
            status=self.status,
            target_group_id=self.target_group_id)


def get_push_group(app_id: Optional[_builtins.str] = None,
                   id: Optional[_builtins.str] = None,
                   source_group_id: Optional[_builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPushGroupResult:
    """
    Get a Push Group assignment for an Application in Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    sample = okta.get_push_group(app_id="<okta_app_id>",
        id="<push_group_mapping_id>")
    another_sample = okta.get_push_group(app_id="<okta_app_id>",
        source_group_id="<okta_source_group_id>")
    ```


    :param _builtins.str app_id: The ID of the Okta Application.
    :param _builtins.str id: Push Group ID
    :param _builtins.str source_group_id: The ID of the source group in Okta.
    """
    __args__ = dict()
    __args__['appId'] = app_id
    __args__['id'] = id
    __args__['sourceGroupId'] = source_group_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getPushGroup:getPushGroup', __args__, opts=opts, typ=GetPushGroupResult).value

    return AwaitableGetPushGroupResult(
        app_id=pulumi.get(__ret__, 'app_id'),
        id=pulumi.get(__ret__, 'id'),
        source_group_id=pulumi.get(__ret__, 'source_group_id'),
        status=pulumi.get(__ret__, 'status'),
        target_group_id=pulumi.get(__ret__, 'target_group_id'))
def get_push_group_output(app_id: Optional[pulumi.Input[_builtins.str]] = None,
                          id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          source_group_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPushGroupResult]:
    """
    Get a Push Group assignment for an Application in Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    sample = okta.get_push_group(app_id="<okta_app_id>",
        id="<push_group_mapping_id>")
    another_sample = okta.get_push_group(app_id="<okta_app_id>",
        source_group_id="<okta_source_group_id>")
    ```


    :param _builtins.str app_id: The ID of the Okta Application.
    :param _builtins.str id: Push Group ID
    :param _builtins.str source_group_id: The ID of the source group in Okta.
    """
    __args__ = dict()
    __args__['appId'] = app_id
    __args__['id'] = id
    __args__['sourceGroupId'] = source_group_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getPushGroup:getPushGroup', __args__, opts=opts, typ=GetPushGroupResult)
    return __ret__.apply(lambda __response__: GetPushGroupResult(
        app_id=pulumi.get(__response__, 'app_id'),
        id=pulumi.get(__response__, 'id'),
        source_group_id=pulumi.get(__response__, 'source_group_id'),
        status=pulumi.get(__response__, 'status'),
        target_group_id=pulumi.get(__response__, 'target_group_id')))
