# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetPushGroupsResult',
    'AwaitableGetPushGroupsResult',
    'get_push_groups',
    'get_push_groups_output',
]

@pulumi.output_type
class GetPushGroupsResult:
    """
    A collection of values returned by getPushGroups.
    """
    def __init__(__self__, app_id=None, id=None, mappings=None):
        if app_id and not isinstance(app_id, str):
            raise TypeError("Expected argument 'app_id' to be a str")
        pulumi.set(__self__, "app_id", app_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if mappings and not isinstance(mappings, list):
            raise TypeError("Expected argument 'mappings' to be a list")
        pulumi.set(__self__, "mappings", mappings)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> _builtins.str:
        """
        The ID of the Okta Application.
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def mappings(self) -> Sequence['outputs.GetPushGroupsMappingResult']:
        """
        List of Push Group mappings for the Application.
        """
        return pulumi.get(self, "mappings")


class AwaitableGetPushGroupsResult(GetPushGroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPushGroupsResult(
            app_id=self.app_id,
            id=self.id,
            mappings=self.mappings)


def get_push_groups(app_id: Optional[_builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPushGroupsResult:
    """
    Gets a list of Push Group mappings for an Application in Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    sample = okta.get_push_groups(app_id="<okta_app_id>")
    pulumi.export("sample", sample.mappings)
    ```


    :param _builtins.str app_id: The ID of the Okta Application.
    """
    __args__ = dict()
    __args__['appId'] = app_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getPushGroups:getPushGroups', __args__, opts=opts, typ=GetPushGroupsResult).value

    return AwaitableGetPushGroupsResult(
        app_id=pulumi.get(__ret__, 'app_id'),
        id=pulumi.get(__ret__, 'id'),
        mappings=pulumi.get(__ret__, 'mappings'))
def get_push_groups_output(app_id: Optional[pulumi.Input[_builtins.str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPushGroupsResult]:
    """
    Gets a list of Push Group mappings for an Application in Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    sample = okta.get_push_groups(app_id="<okta_app_id>")
    pulumi.export("sample", sample.mappings)
    ```


    :param _builtins.str app_id: The ID of the Okta Application.
    """
    __args__ = dict()
    __args__['appId'] = app_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getPushGroups:getPushGroups', __args__, opts=opts, typ=GetPushGroupsResult)
    return __ret__.apply(lambda __response__: GetPushGroupsResult(
        app_id=pulumi.get(__response__, 'app_id'),
        id=pulumi.get(__response__, 'id'),
        mappings=pulumi.get(__response__, 'mappings')))
