# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['FederatedClaimArgs', 'FederatedClaim']

@pulumi.input_type
class FederatedClaimArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[_builtins.str],
                 expression: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a FederatedClaim resource.

        :param pulumi.Input[_builtins.str] app_id: The ID of the application to add the federated claim to.
        :param pulumi.Input[_builtins.str] expression: The Okta Expression Language expression to be evaluated at runtime. See [Okta Expression Language](https://developer.okta.com/docs/reference/okta-expression-language/) for more information.
        :param pulumi.Input[_builtins.str] name: The name of the claim to be used in the produced token.
        """
        pulumi.set(__self__, "app_id", app_id)
        pulumi.set(__self__, "expression", expression)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the application to add the federated claim to.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter
    def expression(self) -> pulumi.Input[_builtins.str]:
        """
        The Okta Expression Language expression to be evaluated at runtime. See [Okta Expression Language](https://developer.okta.com/docs/reference/okta-expression-language/) for more information.
        """
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "expression", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the claim to be used in the produced token.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _FederatedClaimState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 expression: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering FederatedClaim resources.

        :param pulumi.Input[_builtins.str] app_id: The ID of the application to add the federated claim to.
        :param pulumi.Input[_builtins.str] expression: The Okta Expression Language expression to be evaluated at runtime. See [Okta Expression Language](https://developer.okta.com/docs/reference/okta-expression-language/) for more information.
        :param pulumi.Input[_builtins.str] name: The name of the claim to be used in the produced token.
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if expression is not None:
            pulumi.set(__self__, "expression", expression)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the application to add the federated claim to.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter
    def expression(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Okta Expression Language expression to be evaluated at runtime. See [Okta Expression Language](https://developer.okta.com/docs/reference/okta-expression-language/) for more information.
        """
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expression", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the claim to be used in the produced token.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.type_token("okta:app/federatedClaim:FederatedClaim")
class FederatedClaim(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 expression: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a federated claim for an Okta application.

        Federated claims allow you to pass user information from Okta to your app integrations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test_app = okta.app.Saml("test_app",
            label="example",
            sso_url="https://example.com",
            recipient="https://example.com",
            destination="https://example.com",
            audience="https://example.com/audience",
            subject_name_id_template="${user.userName}",
            subject_name_id_format="urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress",
            response_signed=True,
            signature_algorithm="RSA_SHA256",
            digest_algorithm="SHA256")
        example = okta.app.FederatedClaim("example",
            app_id=test_app.id,
            name="role_last_name",
            expression="user.profile.lastName")
        ```

        ### Multiple Claims Example

        ```python
        import pulumi
        import pulumi_okta as okta

        test_app = okta.app.Saml("test_app",
            label="example",
            sso_url="https://example.com",
            recipient="https://example.com",
            destination="https://example.com",
            audience="https://example.com/audience",
            subject_name_id_template="${user.userName}",
            subject_name_id_format="urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress",
            response_signed=True,
            signature_algorithm="RSA_SHA256",
            digest_algorithm="SHA256")
        last_name = okta.app.FederatedClaim("last_name",
            app_id=test_app.id,
            name="lastName",
            expression="user.profile.lastName")
        first_name = okta.app.FederatedClaim("first_name",
            app_id=test_app.id,
            name="firstName",
            expression="user.profile.firstName")
        department = okta.app.FederatedClaim("department",
            app_id=test_app.id,
            name="department",
            expression="user.profile.department")
        ```

        ## Import

        An app federated claim can be imported using the format `app_id/id`:

        ```sh
        $ pulumi import okta:app/federatedClaim:FederatedClaim example <app_id>/<id>
        ```

        Example:

        ```sh
        $ pulumi import okta:app/federatedClaim:FederatedClaim example 0oa1234567890abcdef/clm1234567890abcdef
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: The ID of the application to add the federated claim to.
        :param pulumi.Input[_builtins.str] expression: The Okta Expression Language expression to be evaluated at runtime. See [Okta Expression Language](https://developer.okta.com/docs/reference/okta-expression-language/) for more information.
        :param pulumi.Input[_builtins.str] name: The name of the claim to be used in the produced token.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FederatedClaimArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a federated claim for an Okta application.

        Federated claims allow you to pass user information from Okta to your app integrations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test_app = okta.app.Saml("test_app",
            label="example",
            sso_url="https://example.com",
            recipient="https://example.com",
            destination="https://example.com",
            audience="https://example.com/audience",
            subject_name_id_template="${user.userName}",
            subject_name_id_format="urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress",
            response_signed=True,
            signature_algorithm="RSA_SHA256",
            digest_algorithm="SHA256")
        example = okta.app.FederatedClaim("example",
            app_id=test_app.id,
            name="role_last_name",
            expression="user.profile.lastName")
        ```

        ### Multiple Claims Example

        ```python
        import pulumi
        import pulumi_okta as okta

        test_app = okta.app.Saml("test_app",
            label="example",
            sso_url="https://example.com",
            recipient="https://example.com",
            destination="https://example.com",
            audience="https://example.com/audience",
            subject_name_id_template="${user.userName}",
            subject_name_id_format="urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress",
            response_signed=True,
            signature_algorithm="RSA_SHA256",
            digest_algorithm="SHA256")
        last_name = okta.app.FederatedClaim("last_name",
            app_id=test_app.id,
            name="lastName",
            expression="user.profile.lastName")
        first_name = okta.app.FederatedClaim("first_name",
            app_id=test_app.id,
            name="firstName",
            expression="user.profile.firstName")
        department = okta.app.FederatedClaim("department",
            app_id=test_app.id,
            name="department",
            expression="user.profile.department")
        ```

        ## Import

        An app federated claim can be imported using the format `app_id/id`:

        ```sh
        $ pulumi import okta:app/federatedClaim:FederatedClaim example <app_id>/<id>
        ```

        Example:

        ```sh
        $ pulumi import okta:app/federatedClaim:FederatedClaim example 0oa1234567890abcdef/clm1234567890abcdef
        ```


        :param str resource_name: The name of the resource.
        :param FederatedClaimArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FederatedClaimArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 expression: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FederatedClaimArgs.__new__(FederatedClaimArgs)

            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            if expression is None and not opts.urn:
                raise TypeError("Missing required property 'expression'")
            __props__.__dict__["expression"] = expression
            __props__.__dict__["name"] = name
        super(FederatedClaim, __self__).__init__(
            'okta:app/federatedClaim:FederatedClaim',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[_builtins.str]] = None,
            expression: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None) -> 'FederatedClaim':
        """
        Get an existing FederatedClaim resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: The ID of the application to add the federated claim to.
        :param pulumi.Input[_builtins.str] expression: The Okta Expression Language expression to be evaluated at runtime. See [Okta Expression Language](https://developer.okta.com/docs/reference/okta-expression-language/) for more information.
        :param pulumi.Input[_builtins.str] name: The name of the claim to be used in the produced token.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FederatedClaimState.__new__(_FederatedClaimState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["expression"] = expression
        __props__.__dict__["name"] = name
        return FederatedClaim(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the application to add the federated claim to.
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter
    def expression(self) -> pulumi.Output[_builtins.str]:
        """
        The Okta Expression Language expression to be evaluated at runtime. See [Okta Expression Language](https://developer.okta.com/docs/reference/okta-expression-language/) for more information.
        """
        return pulumi.get(self, "expression")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the claim to be used in the produced token.
        """
        return pulumi.get(self, "name")

