# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetAdminRoleCustomResult',
    'AwaitableGetAdminRoleCustomResult',
    'get_admin_role_custom',
    'get_admin_role_custom_output',
]

@pulumi.output_type
class GetAdminRoleCustomResult:
    """
    A collection of values returned by getAdminRoleCustom.
    """
    def __init__(__self__, description=None, id=None, label=None, permissions=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if label and not isinstance(label, str):
            raise TypeError("Expected argument 'label' to be a str")
        pulumi.set(__self__, "label", label)
        if permissions and not isinstance(permissions, list):
            raise TypeError("Expected argument 'permissions' to be a list")
        pulumi.set(__self__, "permissions", permissions)

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        A human-readable description of the custom role.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier for the custom role. Accepts the role ID or label.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def label(self) -> _builtins.str:
        """
        The name given to the custom role.
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> Sequence[_builtins.str]:
        """
        The permissions that the custom role grants.
        """
        return pulumi.get(self, "permissions")


class AwaitableGetAdminRoleCustomResult(GetAdminRoleCustomResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAdminRoleCustomResult(
            description=self.description,
            id=self.id,
            label=self.label,
            permissions=self.permissions)


def get_admin_role_custom(id: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAdminRoleCustomResult:
    """
    Use this data source to retrieve a custom admin role from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_admin_role_custom(id="<role_id>")
    ```


    :param _builtins.str id: The unique identifier for the custom role. Accepts the role ID or label.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getAdminRoleCustom:getAdminRoleCustom', __args__, opts=opts, typ=GetAdminRoleCustomResult).value

    return AwaitableGetAdminRoleCustomResult(
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        label=pulumi.get(__ret__, 'label'),
        permissions=pulumi.get(__ret__, 'permissions'))
def get_admin_role_custom_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAdminRoleCustomResult]:
    """
    Use this data source to retrieve a custom admin role from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_admin_role_custom(id="<role_id>")
    ```


    :param _builtins.str id: The unique identifier for the custom role. Accepts the role ID or label.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getAdminRoleCustom:getAdminRoleCustom', __args__, opts=opts, typ=GetAdminRoleCustomResult)
    return __ret__.apply(lambda __response__: GetAdminRoleCustomResult(
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        label=pulumi.get(__response__, 'label'),
        permissions=pulumi.get(__response__, 'permissions')))
